@@ -1,7 +1,7 @@
 use super::*;
 use crate::api::media_engine::MIME_TYPE_OPUS;
 use crate::api::APIBuilder;
-use crate::peer::configuration::Configuration;
+use crate::peer::configuration::RTCConfiguration;
 use regex::Regex;
 use std::io::Cursor;
 
@@ -11,7 +11,7 @@ async fn test_opus_case() -> Result<()> {
     m.register_default_codecs()?;
     let api = APIBuilder::new().with_media_engine(m).build();
 
-    let pc = api.new_peer_connection(Configuration::default()).await?;
+    let pc = api.new_peer_connection(RTCConfiguration::default()).await?;
     pc.add_transceiver_from_kind(RTPCodecType::Audio, &[])
         .await?;
 
@@ -31,7 +31,7 @@ async fn test_video_case() -> Result<()> {
     m.register_default_codecs()?;
     let api = APIBuilder::new().with_media_engine(m).build();
 
-    let pc = api.new_peer_connection(Configuration::default()).await?;
+    let pc = api.new_peer_connection(RTCConfiguration::default()).await?;
     pc.add_transceiver_from_kind(RTPCodecType::Video, &[])
         .await?;
 
@@ -185,7 +185,7 @@ a=rtpmap:111 opus/48000/2
             "urn:ietf:params:rtp-hdrext:sdes:repaired-rtp-stream-id",
         ] {
             m.register_header_extension(
-                RTPHeaderExtensionCapability {
+                RTCRtpHeaderExtensionCapability {
                     uri: extension.to_owned(),
                 },
                 RTPCodecType::Audio,
@@ -201,7 +201,7 @@ a=rtpmap:111 opus/48000/2
         assert!(m.negotiated_audio.load(Ordering::SeqCst));
 
         let (abs_id, abs_audio_enabled, abs_video_enabled) = m
-            .get_header_extension_id(RTPHeaderExtensionCapability {
+            .get_header_extension_id(RTCRtpHeaderExtensionCapability {
                 uri: sdp::extmap::ABS_SEND_TIME_URI.to_owned(),
             })
             .await;
@@ -210,7 +210,7 @@ a=rtpmap:111 opus/48000/2
         assert!(!abs_video_enabled);
 
         let (mid_id, mid_audio_enabled, mid_video_enabled) = m
-            .get_header_extension_id(RTPHeaderExtensionCapability {
+            .get_header_extension_id(RTCRtpHeaderExtensionCapability {
                 uri: sdp::extmap::SDES_MID_URI.to_owned(),
             })
             .await;
@@ -233,8 +233,8 @@ a=fmtp:98 level-asymmetry-allowed=1;packetization-mode=1;profile-level-id=42e01f
 ";
         let mut m = MediaEngine::default();
         m.register_codec(
-            RTPCodecParameters {
-                capability: RTPCodecCapability {
+            RTCRtpCodecParameters {
+                capability: RTCRtpCodecCapability {
                     mime_type: MIME_TYPE_H264.to_owned(),
                     clock_rate: 90000,
                     channels: 0,
@@ -272,8 +272,8 @@ a=fmtp:96 level-asymmetry-allowed=1;packetization-mode=1;profile-level-id=640c1f
 ";
         let mut m = MediaEngine::default();
         m.register_codec(
-            RTPCodecParameters {
-                capability: RTPCodecCapability {
+            RTCRtpCodecParameters {
+                capability: RTCRtpCodecCapability {
                     mime_type: MIME_TYPE_H264.to_owned(),
                     clock_rate: 90000,
                     channels: 0,
@@ -306,8 +306,8 @@ a=rtpmap:96 VP9/90000
 ";
         let mut m = MediaEngine::default();
         m.register_codec(
-            RTPCodecParameters {
-                capability: RTPCodecCapability {
+            RTCRtpCodecParameters {
+                capability: RTCRtpCodecCapability {
                     mime_type: MIME_TYPE_VP9.to_owned(),
                     clock_rate: 90000,
                     channels: 0,
@@ -339,8 +339,8 @@ a=rtpmap:96 VP8/90000
 ";
         let mut m = MediaEngine::default();
         m.register_codec(
-            RTPCodecParameters {
-                capability: RTPCodecCapability {
+            RTCRtpCodecParameters {
+                capability: RTCRtpCodecCapability {
                     mime_type: MIME_TYPE_VP8.to_owned(),
                     clock_rate: 90000,
                     channels: 0,
@@ -376,8 +376,8 @@ a=fmtp:97 apt=96
 ";
         let mut m = MediaEngine::default();
         m.register_codec(
-            RTPCodecParameters {
-                capability: RTPCodecCapability {
+            RTCRtpCodecParameters {
+                capability: RTCRtpCodecCapability {
                     mime_type: MIME_TYPE_VP8.to_owned(),
                     clock_rate: 90000,
                     channels: 0,
@@ -391,8 +391,8 @@ a=fmtp:97 apt=96
         )?;
 
         m.register_codec(
-            RTPCodecParameters {
-                capability: RTPCodecCapability {
+            RTCRtpCodecParameters {
+                capability: RTCRtpCodecCapability {
                     mime_type: MIME_TYPE_VP9.to_owned(),
                     clock_rate: 90000,
                     channels: 0,
@@ -406,8 +406,8 @@ a=fmtp:97 apt=96
         )?;
 
         m.register_codec(
-            RTPCodecParameters {
-                capability: RTPCodecCapability {
+            RTCRtpCodecParameters {
+                capability: RTCRtpCodecCapability {
                     mime_type: "video/rtx".to_owned(),
                     clock_rate: 90000,
                     channels: 0,
@@ -443,8 +443,8 @@ a=fmtp:97 apt=96
 ";
         let mut m = MediaEngine::default();
         m.register_codec(
-            RTPCodecParameters {
-                capability: RTPCodecCapability {
+            RTCRtpCodecParameters {
+                capability: RTCRtpCodecCapability {
                     mime_type: MIME_TYPE_VP8.to_owned(),
                     clock_rate: 90000,
                     channels: 0,
@@ -458,8 +458,8 @@ a=fmtp:97 apt=96
         )?;
 
         m.register_codec(
-            RTPCodecParameters {
-                capability: RTPCodecCapability {
+            RTCRtpCodecParameters {
+                capability: RTCRtpCodecCapability {
                     mime_type: MIME_TYPE_VP9.to_owned(),
                     clock_rate: 90000,
                     channels: 0,
@@ -473,8 +473,8 @@ a=fmtp:97 apt=96
         )?;
 
         m.register_codec(
-            RTPCodecParameters {
-                capability: RTPCodecCapability {
+            RTCRtpCodecParameters {
+                capability: RTCRtpCodecCapability {
                     mime_type: "video/rtx".to_owned(),
                     clock_rate: 90000,
                     channels: 0,
@@ -506,8 +506,8 @@ a=fmtp:97 apt=96
 async fn test_media_engine_header_extension_direction() -> Result<()> {
     let register_codec = |m: &mut MediaEngine| -> Result<()> {
         m.register_codec(
-            RTPCodecParameters {
-                capability: RTPCodecCapability {
+            RTCRtpCodecParameters {
+                capability: RTCRtpCodecCapability {
                     mime_type: MIME_TYPE_OPUS.to_owned(),
                     clock_rate: 48000,
                     channels: 0,
@@ -526,7 +526,7 @@ async fn test_media_engine_header_extension_direction() -> Result<()> {
         let mut m = MediaEngine::default();
         register_codec(&mut m)?;
         m.register_header_extension(
-            RTPHeaderExtensionCapability {
+            RTCRtpHeaderExtensionCapability {
                 uri: "webrtc-header-test".to_owned(),
             },
             RTPCodecType::Audio,
@@ -535,7 +535,10 @@ async fn test_media_engine_header_extension_direction() -> Result<()> {
         .await?;
 
         let params = m
-            .get_rtp_parameters_by_kind(RTPCodecType::Audio, &[RTPTransceiverDirection::Recvonly])
+            .get_rtp_parameters_by_kind(
+                RTPCodecType::Audio,
+                &[RTCRtpTransceiverDirection::Recvonly],
+            )
             .await;
 
         assert_eq!(1, params.header_extensions.len());
@@ -546,16 +549,19 @@ async fn test_media_engine_header_extension_direction() -> Result<()> {
         let mut m = MediaEngine::default();
         register_codec(&mut m)?;
         m.register_header_extension(
-            RTPHeaderExtensionCapability {
+            RTCRtpHeaderExtensionCapability {
                 uri: "webrtc-header-test".to_owned(),
             },
             RTPCodecType::Audio,
-            vec![RTPTransceiverDirection::Recvonly],
+            vec![RTCRtpTransceiverDirection::Recvonly],
         )
         .await?;
 
         let params = m
-            .get_rtp_parameters_by_kind(RTPCodecType::Audio, &[RTPTransceiverDirection::Recvonly])
+            .get_rtp_parameters_by_kind(
+                RTPCodecType::Audio,
+                &[RTCRtpTransceiverDirection::Recvonly],
+            )
             .await;
 
         assert_eq!(1, params.header_extensions.len());
@@ -566,16 +572,19 @@ async fn test_media_engine_header_extension_direction() -> Result<()> {
         let mut m = MediaEngine::default();
         register_codec(&mut m)?;
         m.register_header_extension(
-            RTPHeaderExtensionCapability {
+            RTCRtpHeaderExtensionCapability {
                 uri: "webrtc-header-test".to_owned(),
             },
             RTPCodecType::Audio,
-            vec![RTPTransceiverDirection::Sendonly],
+            vec![RTCRtpTransceiverDirection::Sendonly],
         )
         .await?;
 
         let params = m
-            .get_rtp_parameters_by_kind(RTPCodecType::Audio, &[RTPTransceiverDirection::Recvonly])
+            .get_rtp_parameters_by_kind(
+                RTPCodecType::Audio,
+                &[RTCRtpTransceiverDirection::Recvonly],
+            )
             .await;
 
         assert_eq!(0, params.header_extensions.len());
@@ -588,11 +597,11 @@ async fn test_media_engine_header_extension_direction() -> Result<()> {
 
         let result = m
             .register_header_extension(
-                RTPHeaderExtensionCapability {
+                RTCRtpHeaderExtensionCapability {
                     uri: "webrtc-header-test".to_owned(),
                 },
                 RTPCodecType::Audio,
-                vec![RTPTransceiverDirection::Sendrecv],
+                vec![RTCRtpTransceiverDirection::Sendrecv],
             )
             .await;
         if let Err(err) = result {
@@ -603,11 +612,11 @@ async fn test_media_engine_header_extension_direction() -> Result<()> {
 
         let result = m
             .register_header_extension(
-                RTPHeaderExtensionCapability {
+                RTCRtpHeaderExtensionCapability {
                     uri: "webrtc-header-test".to_owned(),
                 },
                 RTPCodecType::Audio,
-                vec![RTPTransceiverDirection::Inactive],
+                vec![RTCRtpTransceiverDirection::Inactive],
             )
             .await;
         if let Err(err) = result {
@@ -617,11 +626,11 @@ async fn test_media_engine_header_extension_direction() -> Result<()> {
         }
         let result = m
             .register_header_extension(
-                RTPHeaderExtensionCapability {
+                RTCRtpHeaderExtensionCapability {
                     uri: "webrtc-header-test".to_owned(),
                 },
                 RTPCodecType::Audio,
-                vec![RTPTransceiverDirection::Unspecified],
+                vec![RTCRtpTransceiverDirection::Unspecified],
             )
             .await;
         if let Err(err) = result {
@@ -640,8 +649,8 @@ async fn test_media_engine_double_register() -> Result<()> {
     let mut m = MediaEngine::default();
 
     m.register_codec(
-        RTPCodecParameters {
-            capability: RTPCodecCapability {
+        RTCRtpCodecParameters {
+            capability: RTCRtpCodecCapability {
                 mime_type: MIME_TYPE_OPUS.to_owned(),
                 clock_rate: 48000,
                 channels: 0,
@@ -655,8 +664,8 @@ async fn test_media_engine_double_register() -> Result<()> {
     )?;
 
     m.register_codec(
-        RTPCodecParameters {
-            capability: RTPCodecCapability {
+        RTCRtpCodecParameters {
+            capability: RTCRtpCodecCapability {
                 mime_type: MIME_TYPE_OPUS.to_owned(),
                 clock_rate: 48000,
                 channels: 0,
@@ -678,7 +687,7 @@ async fn validate(m: &MediaEngine) -> Result<()> {
         .await?;
 
     let (id, audio_negotiated, video_negotiated) = m
-        .get_header_extension_id(RTPHeaderExtensionCapability {
+        .get_header_extension_id(RTCRtpHeaderExtensionCapability {
             uri: "test-extension".to_owned(),
         })
         .await;
@@ -695,8 +704,8 @@ async fn test_update_header_extenstion_to_cloned_media_engine() -> Result<()> {
     let mut m = MediaEngine::default();
 
     m.register_codec(
-        RTPCodecParameters {
-            capability: RTPCodecCapability {
+        RTCRtpCodecParameters {
+            capability: RTCRtpCodecCapability {
                 mime_type: MIME_TYPE_OPUS.to_owned(),
                 clock_rate: 48000,
                 channels: 0,
@@ -710,7 +719,7 @@ async fn test_update_header_extenstion_to_cloned_media_engine() -> Result<()> {
     )?;
 
     m.register_header_extension(
-        RTPHeaderExtensionCapability {
+        RTCRtpHeaderExtensionCapability {
             uri: "test-extension".to_owned(),
         },
         RTPCodecType::Audio,
