@@ -1,27 +1,27 @@
-use super::sdp_type::SDPType;
+use super::sdp_type::RTCSdpType;
 
 use anyhow::Result;
 use serde::{Deserialize, Serialize};
 use std::io::Cursor;
 
 #[derive(Default, Debug, Clone, PartialEq, Serialize, Deserialize)]
-pub struct SessionDescriptionSerde {
+pub struct RTCSessionDescriptionSerde {
     #[serde(rename = "type")]
-    pub sdp_type: SDPType,
+    pub sdp_type: RTCSdpType,
 
     pub sdp: String,
 }
 
 /// SessionDescription is used to expose local and remote session descriptions.
 #[derive(Default, Debug, Clone)]
-pub struct SessionDescription {
-    pub serde: SessionDescriptionSerde,
+pub struct RTCSessionDescription {
+    pub serde: RTCSessionDescriptionSerde,
     /// This will never be initialized by callers, internal use only
     pub(crate) parsed: Option<sdp::session_description::SessionDescription>,
 }
 
 /// Unmarshal is a helper to deserialize the sdp
-impl SessionDescription {
+impl RTCSessionDescription {
     pub fn unmarshal(&self) -> Result<sdp::session_description::SessionDescription> {
         let mut reader = Cursor::new(self.serde.sdp.as_bytes());
         let parsed = sdp::session_description::SessionDescription::unmarshal(&mut reader)?;
@@ -34,15 +34,15 @@ mod test {
     use super::*;
     use crate::api::media_engine::MediaEngine;
     use crate::api::APIBuilder;
-    use crate::peer::configuration::Configuration;
+    use crate::peer::configuration::RTCConfiguration;
 
     #[test]
     fn test_session_description_json() {
         let tests = vec![
             (
-                SessionDescription {
-                    serde: SessionDescriptionSerde {
-                        sdp_type: SDPType::Offer,
+                RTCSessionDescription {
+                    serde: RTCSessionDescriptionSerde {
+                        sdp_type: RTCSdpType::Offer,
                         sdp: "sdp".to_owned(),
                     },
                     parsed: None,
@@ -50,9 +50,9 @@ mod test {
                 r#"{"type":"offer","sdp":"sdp"}"#,
             ),
             (
-                SessionDescription {
-                    serde: SessionDescriptionSerde {
-                        sdp_type: SDPType::Pranswer,
+                RTCSessionDescription {
+                    serde: RTCSessionDescriptionSerde {
+                        sdp_type: RTCSdpType::Pranswer,
                         sdp: "sdp".to_owned(),
                     },
                     parsed: None,
@@ -60,9 +60,9 @@ mod test {
                 r#"{"type":"pranswer","sdp":"sdp"}"#,
             ),
             (
-                SessionDescription {
-                    serde: SessionDescriptionSerde {
-                        sdp_type: SDPType::Answer,
+                RTCSessionDescription {
+                    serde: RTCSessionDescriptionSerde {
+                        sdp_type: RTCSdpType::Answer,
                         sdp: "sdp".to_owned(),
                     },
                     parsed: None,
@@ -70,9 +70,9 @@ mod test {
                 r#"{"type":"answer","sdp":"sdp"}"#,
             ),
             (
-                SessionDescription {
-                    serde: SessionDescriptionSerde {
-                        sdp_type: SDPType::Rollback,
+                RTCSessionDescription {
+                    serde: RTCSessionDescriptionSerde {
+                        sdp_type: RTCSdpType::Rollback,
                         sdp: "sdp".to_owned(),
                     },
                     parsed: None,
@@ -80,9 +80,9 @@ mod test {
                 r#"{"type":"rollback","sdp":"sdp"}"#,
             ),
             (
-                SessionDescription {
-                    serde: SessionDescriptionSerde {
-                        sdp_type: SDPType::Unspecified,
+                RTCSessionDescription {
+                    serde: RTCSessionDescriptionSerde {
+                        sdp_type: RTCSdpType::Unspecified,
                         sdp: "sdp".to_owned(),
                     },
                     parsed: None,
@@ -97,7 +97,7 @@ mod test {
             let desc_data = result.unwrap();
             assert_eq!(desc_data, expected_string, "string is not expected");
 
-            let result = serde_json::from_str::<SessionDescriptionSerde>(&desc_data);
+            let result = serde_json::from_str::<RTCSessionDescriptionSerde>(&desc_data);
             assert!(result.is_ok(), "testCase: unmarshal err: {:?}", result);
             assert_eq!(result.unwrap(), desc.serde);
         }
@@ -109,12 +109,12 @@ mod test {
         m.register_default_codecs()?;
         let api = APIBuilder::new().with_media_engine(m).build();
 
-        let pc = api.new_peer_connection(Configuration::default()).await?;
+        let pc = api.new_peer_connection(RTCConfiguration::default()).await?;
 
         let offer = pc.create_offer(None).await?;
 
-        let desc = SessionDescription {
-            serde: SessionDescriptionSerde {
+        let desc = RTCSessionDescription {
+            serde: RTCSessionDescriptionSerde {
                 sdp_type: offer.serde.sdp_type,
                 sdp: offer.serde.sdp,
             },
